<!-- load mixpanel.com API library start -->
<script type="text/javascript" src="http://api.mixpanel.com/site_media/js/api/mixpanel_fb.js"></script>
<script type="text/javascript">
try {
var mpmetrics = new MixpanelLib("{{ mp_api_token }}");
} catch(err) {
null_fn = function () {};
var mpmetrics = { track: null_fn, track_funnel: null_fn };
}
</script> 
<script src="{{ mp_common_events_js }}" type="text/javascript"></script>
<!-- load mixpanel.com API library end -->
