<!-- load mixpanel.com API library start -->
<script type="text/javascript">
  // change token string at here
  var MP_API_TOKEN = "{{ mp_api_token }}";
  
  var MP_LOAD_TYPE = "async";
  
  // async load mixpanel library
  var mpq = [];
  mpq.push(["init", MP_API_TOKEN]);
  (function(){
      var mp = document.createElement("script");
      mp.type = "text/javascript";
      mp.async = true;
      mp.src = (document.location.protocol == 'https:' ? 'https:' : 'http:') + "//api.mixpanel.com/site_media/js/api/mixpanel.js";
      var s = document.getElementsByTagName("script")[0];
      s.parentNode.insertBefore(mp, s);
  })();
</script>
<script src="{{ mp_common_events_js }}" type="text/javascript"></script>
<!-- load mixpanel.com API library end -->
