<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
{% load mp_tags %}
<html lang="en">
  <head>
    <meta http-equiv="Content-Type" content="text/html;charset=UTF-8">
    <title></title>
    <script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.4.4/jquery.js">
    </script>
    {% mp_init async %}
    <script type="text/javascript">
      $(document).ready(function(){
          trackMixpanelEvent('index page loaded', {});
          trackfunnelMixpanelEvent('index page opend', 1, 'load page done', {});
      });
    </script>
  </head>
  <body>
    <!-- append callback function -->
    <a href="javascript:void(0);" onclick="trackfunnelMixpanelEvent('index page opend', 2, 'click button', {})" >click me</a>
  </body>
</html>
