<!-- load mixpanel.com API library start -->
<script type="text/javascript">
  // change token string at here
  var MP_API_TOKEN = "{{ mp_token }}";
  
  var MP_LOAD_TYPE = "standard";
    
  // standard load mixpanel library
  var mp_protocol = (("https:" == document.location.protocol) ? "https://" : "http://");
  document.write(unescape("%3Cscript src='" + mp_protocol + "api.mixpanel.com/site_media/js/api/mixpanel.js' type='text/javascript'%3E%3C/script%3E"));
  // init mixpanel
  try {
      var mpmetrics = new MixpanelLib(MP_API_TOKEN);
  } 
  catch (err) {
      var null_fn = function(){};
      var mpmetrics = {
          track: null_fn,
          track_funnel: null_fn,
          register: null_fn,
          register_once: null_fn,
          register_funnel: null_fn,
          identify: null_fn
      };
  }
</script>
<script src="{{ mp_common_events_js }}" type="text/javascript"></script>
<!-- load mixpanel.com API library end -->
